#!/bin/bash

# This file will be overwritten whenever voxl-utils is updated,
# Any customizations to your environment should be made in ~/.bashrc

# ModalAI bash formatting

cursor-position()
{
    local CURPOS
    read -sdR -p $'\E[6n' CURPOS
    CURPOS=${CURPOS#*[} # Strip decoration characters <ESC>[
    echo "${CURPOS}"    # Return position in "row;col" format
}
cursor-row()
{
    local COL
    local ROW
    IFS=';' read -sdR -p $'\E[6n' ROW COL
    echo "${ROW#*[}"
}
cursor-col()
{
    local COL
    local ROW
    IFS=';' read -sdR -p $'\E[6n' ROW COL
    echo "${COL}"
}


__gotoxy(){

    echo -ne "\033[$2;$1H"
}

__scrollable_clear_terminal() {

    local numrows=$(tput lines)

    echo

    local i
    for (( i=1 ; i < $numrows ; i++ )) ; do
        echo -e ${CLEAR_LINE}
    done

    __gotoxy 0 0

}

__print_progress_bar(){

    if [ $# -eq 3 ] ; then
        NUM_CHARS=$3
    else
        # 10 is number of characters in "](xxx%) " at the end of the line
        # plus one "[" at the beginning and one extra at the end so that
        # ctrl+c doesn't run over
        NUM_CHARS=$((COLUMNS - 10))
    fi

    ((PCT=$1*100/$2))
    ((VAL=$PCT*$NUM_CHARS/100))

    local STRING="\r["

    local i
    for i in $(seq 1 $NUM_CHARS); do

        if [ $VAL -ge $i ]; then
            STRING="${STRING}-"
        else
            STRING="${STRING} "
        fi
    done
    STRING="${STRING}]($(printf "%3d" $PCT)%)"
    echo -ne "$STRING"
}


export RESET_ALL="\033[0m"

export CLEAR_TERMINAL="\033c"
export DISABLE_WRAP="\033[?7l"
export ENABLE_WRAP="\033[?7h"
export CLEAR_LINE="\033[2K"

export SET_BOLD="\033[1m"
export SET_DIM="\033[2m"
export SET_UNDERLINE="\033[4m"
export SET_BLINK="\033[5m"
export SET_INVERT="\033[7m"
export SET_HIDDEN="\033[8m"
export SET_STRIKETHROUGH="\033[9m"

export RESET_BOLD="\033[21m"
export RESET_DIM="\033[22m"
export RESET_UNDERLINE="\033[24m"
export RESET_BLINK="\033[25m"
export RESET_INVERT="\033[27m"
export RESET_HIDDEN="\033[28m"

export CLR_RESET="\033[39m"

export CLR_BLK="\033[30m"
export CLR_RED="\033[31m"
export CLR_GRN="\033[32m"
export CLR_YLW="\033[33m"
export CLR_BLU="\033[34m"
export CLR_MAG="\033[35m"
export CLR_CYN="\033[36m"
export CLR_LIT_GRY="\033[37m"

export CLR_DRK_GRY="\033[90m"
export CLR_LIT_RED="\033[91m"
export CLR_LIT_GRN="\033[92m"
export CLR_LIT_YLW="\033[93m"
export CLR_LIT_BLU="\033[94m"
export CLR_LIT_MAG="\033[95m"
export CLR_LIT_CYN="\033[96m"
export CLR_WHT="\033[97m"

export CLR_BKG_RESET="\033[49m"

export CLR_BKG_BLK="\033[40m"
export CLR_BKG_RED="\033[41m"
export CLR_BKG_GRN="\033[42m"
export CLR_BKG_YLW="\033[43m"
export CLR_BKG_BLU="\033[44m"
export CLR_BKG_MAG="\033[45m"
export CLR_BKG_CYN="\033[46m"
export CLR_BKG_LIT_GRY="\033[47m"

export CLR_BKG_DRK_GRY="\033[100m"
export CLR_BKG_LIT_RED="\033[101m"
export CLR_BKG_LIT_GRN="\033[102m"
export CLR_BKG_LIT_YLW="\033[103m"
export CLR_BKG_LIT_BLU="\033[104m"
export CLR_BKG_LIT_MAG="\033[105m"
export CLR_BKG_LIT_CYN="\033[106m"
export CLR_BKG_WHT="\033[107m"

export RAW_RESET_ALL="\[\e[0m\]"

export RAW_CLEAR_TERMINAL="\[\ec\]"
export RAW_DISABLE_WRAP="\[\e[?7l\]"
export RAW_ENABLE_WRAP="\[\e[?7h\]"
export RAW_CLEAR_LINE="\[\e[2K\]"

export RAW_SET_BOLD="\[\e[1m\]"
export RAW_SET_DIM="\[\e[2m\]"
export RAW_SET_UNDERLINE="\[\e[4m\]"
export RAW_SET_BLINK="\[\e[5m\]"
export RAW_SET_INVERT="\[\e[7m\]"
export RAW_SET_HIDDEN="\[\e[8m\]"
export RAW_SET_STRIKETHROUGH="\[\e[8m\]"

export RAW_RESET_BOLD="\[\e[21m\]"
export RAW_RESET_DIM="\[\e[22m\]"
export RAW_RESET_UNDERLINE="\[\e[24m\]"
export RAW_RESET_BLINK="\[\e[25m\]"
export RAW_RESET_INVERT="\[\e[27m\]"
export RAW_RESET_HIDDEN="\[\e[28m\]"

export RAW_CLR_RESET="\[\e[39m\]"

export RAW_CLR_BLK="\[\e[30m\]"
export RAW_CLR_RED="\[\e[31m\]"
export RAW_CLR_GRN="\[\e[32m\]"
export RAW_CLR_YLW="\[\e[33m\]"
export RAW_CLR_BLU="\[\e[34m\]"
export RAW_CLR_MAG="\[\e[35m\]"
export RAW_CLR_CYN="\[\e[36m\]"
export RAW_CLR_LIT_GRY="\[\e[37m\]"

export RAW_CLR_DRK_GRY="\[\e[90m\]"
export RAW_CLR_LIT_RED="\[\e[91m\]"
export RAW_CLR_LIT_GRN="\[\e[92m\]"
export RAW_CLR_LIT_YLW="\[\e[93m\]"
export RAW_CLR_LIT_BLU="\[\e[94m\]"
export RAW_CLR_LIT_MAG="\[\e[95m\]"
export RAW_CLR_LIT_CYN="\[\e[96m\]"
export RAW_CLR_WHT="\[\e[97m\]"

export RAW_CLR_BKG_RESET="\[\e[49m\]"

export RAW_CLR_BKG_BLK="\[\e[40m\]"
export RAW_CLR_BKG_RED="\[\e[41m\]"
export RAW_CLR_BKG_GRN="\[\e[42m\]"
export RAW_CLR_BKG_YLW="\[\e[43m\]"
export RAW_CLR_BKG_BLU="\[\e[44m\]"
export RAW_CLR_BKG_MAG="\[\e[45m\]"
export RAW_CLR_BKG_CYN="\[\e[46m\]"
export RAW_CLR_BKG_LIT_GRY="\[\e[47m\]"

export RAW_CLR_BKG_DRK_GRY="\[\e[100m\]"
export RAW_CLR_BKG_LIT_RED="\[\e[101m\]"
export RAW_CLR_BKG_LIT_GRN="\[\e[102m\]"
export RAW_CLR_BKG_LIT_YLW="\[\e[103m\]"
export RAW_CLR_BKG_LIT_BLU="\[\e[104m\]"
export RAW_CLR_BKG_LIT_MAG="\[\e[105m\]"
export RAW_CLR_BKG_LIT_CYN="\[\e[106m\]"
export RAW_CLR_BKG_WHT="\[\e[107m\]"
